@@ -8,6 +8,8 @@ from typing import Dict, AsyncIterable, Optional, Any, Union
 from AgentCrew.modules.agents import AgentManager, LocalAgent
 from AgentCrew.modules.agents.base import MessageType
 from AgentCrew.modules import logger
+import tempfile
+import os
 
 from a2a.types import (
     CancelTaskResponse,
@@ -55,6 +57,7 @@ class AgentTaskManager(TaskManager):
         self.tasks: Dict[str, Task] = {}
         self.task_history: Dict[str, list[Dict[str, Any]]] = {}
         self.streaming_tasks: Dict[str, asyncio.Queue] = {}
+        self.file_handler = None
 
     async def on_send_message(
         self, request: SendMessageRequest | SendStreamingMessageRequest
@@ -79,8 +82,6 @@ class AgentTaskManager(TaskManager):
                 )
             )
 
-        agent.activate()
-
         # Generate task ID from message
         task_id = (
             request.params.message.taskId or f"task_{request.params.message.messageId}"
@@ -90,7 +91,7 @@ class AgentTaskManager(TaskManager):
             # Create task with initial state
             task = Task(
                 id=task_id,
-                contextId=request.params.message.contextId or f"ctx_{task_id}",
+                context_id=request.params.message.contextId or f"ctx_{task_id}",
                 status=TaskStatus(
                     state=TaskState.working, timestamp=datetime.now().isoformat()
                 ),
@@ -103,6 +104,26 @@ class AgentTaskManager(TaskManager):
 
         # Convert A2A message to SwissKnife format
         message = convert_a2a_message_to_agent(request.params.message)
+        if next(
+            (m for m in message.get("content", []) if m.get("type", "text") == "file"),
+            None,
+        ):
+            from AgentCrew.modules.chat.file_handler import FileHandler
+
+            new_parts = []
+            if self.file_handler is None:
+                self.file_handler = FileHandler()
+            for part in message.get("content", []):
+                if part.get("type") == "file":
+                    temp_file = os.path.join(tempfile.gettempdir(), part["file_name"])
+                    with open(temp_file, "wb") as f:
+                        f.write(part["file_data"])
+                    new_parts.append(self.file_handler.process_file(temp_file))
+                else:
+                    new_parts.append(part)
+
+            message["content"] = new_parts
+
         self.task_history[task_id].append(message)
 
         # Process with agent (non-blocking)
@@ -172,6 +193,9 @@ class AgentTaskManager(TaskManager):
             if task.id not in self.task_history:
                 raise ValueError("Task history is not existed")
 
+            input_tokens = 0
+            output_tokens = 0
+
             async def _process_task():
                 # Process with agent
 
@@ -180,12 +204,21 @@ class AgentTaskManager(TaskManager):
                 response_message = ""
                 thinking_content = ""
                 thinking_signature = ""
+                tool_uses = []
+
+                def process_result(_tool_uses, _input_tokens, _output_tokens):
+                    nonlocal tool_uses, input_tokens, output_tokens
+                    tool_uses = _tool_uses
+                    input_tokens += _input_tokens
+                    output_tokens += _output_tokens
 
                 async for (
                     response_message,
                     chunk_text,
                     thinking_chunk,
-                ) in agent.process_messages(self.task_history[task.id]):
+                ) in agent.process_messages(
+                    self.task_history[task.id], callback=process_result
+                ):
                     # Update current response
                     if response_message:
                         current_response = response_message
@@ -205,8 +238,8 @@ class AgentTaskManager(TaskManager):
                                 thinking_content += think_text_chunk
                                 await queue.put(
                                     TaskStatusUpdateEvent(
-                                        taskId=task.id,
-                                        contextId=task.contextId,
+                                        task_id=task.id,
+                                        context_id=task.context_id,
                                         status=TaskStatus(
                                             state=TaskState.working,
                                             message=convert_agent_message_to_a2a(
@@ -231,14 +264,12 @@ class AgentTaskManager(TaskManager):
                             )
                             await queue.put(
                                 TaskArtifactUpdateEvent(
-                                    taskId=task.id,
-                                    contextId=task.contextId,
+                                    task_id=task.id,
+                                    context_id=task.context_id,
                                     artifact=artifact,
                                 )
                             )
 
-                # Get final result
-                tool_uses, input_tokens, output_tokens = agent.get_process_result()
                 if tool_uses and len(tool_uses) > 0:
                     # Add thinking content as a separate message if available
                     thinking_data = (
@@ -267,6 +298,21 @@ class AgentTaskManager(TaskManager):
 
                     # Process each tool use
                     for tool_use in tool_uses:
+                        if task.id in self.streaming_tasks:
+                            queue = self.streaming_tasks[task.id]
+
+                            artifact = convert_agent_response_to_a2a_artifact(
+                                f"\n```tool_call\ntool_name: {tool_use['name']}\nInput: {tool_use['input']}\n```",
+                                artifact_id=f"artifact_{task.id}_{len(artifacts)}",
+                            )
+                            await queue.put(
+                                TaskArtifactUpdateEvent(
+                                    task_id=task.id,
+                                    context_id=task.context_id,
+                                    artifact=artifact,
+                                )
+                            )
+
                         try:
                             tool_result = await agent.execute_tool_call(
                                 tool_use["name"],
@@ -291,6 +337,21 @@ class AgentTaskManager(TaskManager):
                             )
                             if error_message:
                                 self.task_history[task.id].append(error_message)
+
+                    if task.id in self.streaming_tasks:
+                        queue = self.streaming_tasks[task.id]
+
+                        artifact = convert_agent_response_to_a2a_artifact(
+                            "\n",
+                            artifact_id=f"artifact_{task.id}_{len(artifacts)}",
+                        )
+                        await queue.put(
+                            TaskArtifactUpdateEvent(
+                                task_id=task.id,
+                                context_id=task.context_id,
+                                artifact=artifact,
+                            )
+                        )
                     await _process_task()
                 return current_response
 
@@ -323,8 +384,8 @@ class AgentTaskManager(TaskManager):
                 # Send final status
                 await queue.put(
                     TaskStatusUpdateEvent(
-                        taskId=task.id,
-                        contextId=task.contextId,
+                        task_id=task.id,
+                        context_id=task.context_id,
                         status=task.status,
                         final=True,
                     )
@@ -344,8 +405,8 @@ class AgentTaskManager(TaskManager):
                 queue = self.streaming_tasks[task.id]
                 await queue.put(
                     TaskStatusUpdateEvent(
-                        taskId=task.id,
-                        contextId=task.contextId,
+                        task_id=task.id,
+                        context_id=task.context_id,
                         status=task.status,
                         final=True,
                     )
@@ -409,8 +470,8 @@ class AgentTaskManager(TaskManager):
             queue = self.streaming_tasks[task_id]
             await queue.put(
                 TaskStatusUpdateEvent(
-                    taskId=task_id,
-                    contextId=task.contextId,
+                    task_id=task_id,
+                    context_id=task.context_id,
                     status=task.status,
                     final=True,
                 )
