@@ -1,6 +1,6 @@
 from datetime import datetime
 import os
-from typing import Dict, Any, List, Optional
+from typing import Dict, Any, List, Optional, Callable
 from AgentCrew.modules.llm.base import BaseLLMService
 from AgentCrew.modules.llm.message import MessageTransformer
 from AgentCrew.modules.agents.base import BaseAgent, MessageType
@@ -18,6 +18,7 @@ class LocalAgent(BaseAgent):
         services: Dict[str, Any],
         tools: List[str],
         temperature: Optional[float] = None,
+        is_remoting_mode: bool = False,
     ):
         """
         Initialize a new agent.
@@ -38,6 +39,7 @@ class LocalAgent(BaseAgent):
         self.system_prompt = None
         self.custom_system_prompt = None
         self.tool_prompts = []
+        self.is_remoting_mode = is_remoting_mode
         # self.history = []
         # self.shared_context_pool: Dict[str, List[int]] = {}
         # Store tool definitions in the same format as ToolRegistry
@@ -46,8 +48,6 @@ class LocalAgent(BaseAgent):
             set()
         )  # Set of tool names that are registered with the LLM
 
-        self.register_tools()
-
     def _extract_tool_name(self, tool_def: Any) -> str:
         """
         Extract tool name from definition regardless of format.
@@ -73,7 +73,7 @@ class LocalAgent(BaseAgent):
         Register tools for this agent using the services dictionary.
         """
 
-        if self.services.get("agent_manager"):
+        if self.services.get("agent_manager") and not self.is_remoting_mode:
             from AgentCrew.modules.agents.tools.transfer import (
                 register as register_transfer,
             )
@@ -210,16 +210,25 @@ class LocalAgent(BaseAgent):
         if not self.llm:
             return False
 
+        if self.is_active:
+            return True  # Already active
+
+        from AgentCrew.modules.mcpclient.manager import MCPSessionManager
+
+        self.register_tools()
         self._register_tools_with_llm()
+
+        # Reinitialize MCP session manager for the current agent
+        if not self.is_remoting_mode:
+            mcp_manager = MCPSessionManager.get_instance()
+            if mcp_manager.initialized:
+                mcp_manager.initialize_for_agent(self.name)
+
         system_prompt = self.get_system_prompt()
         if self.custom_system_prompt:
-            system_prompt = (
-                self.get_system_prompt()
-                + "\n---\n\n"
-                + self.custom_system_prompt
-                + "\n---\n\n"
-                + "\n".join(self.tool_prompts)
-            )
+            system_prompt = system_prompt + "\n---\n\n" + self.custom_system_prompt
+        if self.tool_prompts:
+            system_prompt = system_prompt + "\n---\n\n" + "\n".join(self.tool_prompts)
 
         self.llm.set_system_prompt(system_prompt)
         self.llm.temperature = self.temperature if self.temperature is not None else 0.4
@@ -237,6 +246,7 @@ class LocalAgent(BaseAgent):
             return False
 
         self._clear_tools_from_llm()
+        self.tool_definitions = {}
         self.is_active = False
         return True
 
@@ -375,7 +385,11 @@ class LocalAgent(BaseAgent):
 
         return True
 
-    async def process_messages(self, messages: Optional[List[Dict[str, Any]]] = None):
+    async def process_messages(
+        self,
+        messages: Optional[List[Dict[str, Any]]] = None,
+        callback: Optional[Callable] = None,
+    ):
         """
         Process messages using this agent.
 
@@ -390,14 +404,15 @@ class LocalAgent(BaseAgent):
         )
 
         assistant_response = ""
-        self.tool_uses = []
-        self.input_tokens_usage = 0
-        self.output_tokens_usage = 0
+        _tool_uses = []
+        _input_tokens_usage = 0
+        _output_tokens_usage = 0
         # Ensure the first message is a system message with the agent's prompt
         if not messages:
             final_messages = list(self.history)
         else:
             final_messages = list(messages)
+            print(messages)
         if "context_persistent" in self.services and isinstance(
             self.services["context_persistent"], ContextPersistenceService
         ):
@@ -441,15 +456,23 @@ class LocalAgent(BaseAgent):
                         chunk_text,
                         thinking_chunk,
                     ) = self.llm.process_stream_chunk(
-                        chunk, assistant_response, self.tool_uses
+                        chunk, assistant_response, _tool_uses
                     )
-                    if tool_uses:
-                        self.tool_uses = tool_uses
-                    if chunk_input_tokens > 0:
-                        self.input_tokens_usage = chunk_input_tokens
-                    if chunk_output_tokens > 0:
-                        self.output_tokens_usage = chunk_output_tokens
                     yield (assistant_response, chunk_text, thinking_chunk)
+
+                    if tool_uses:
+                        _tool_uses = tool_uses
+                    if chunk_input_tokens > 0:
+                        _input_tokens_usage = chunk_input_tokens
+                    if chunk_output_tokens > 0:
+                        _output_tokens_usage = chunk_output_tokens
+            if callback:
+                callback(_tool_uses, _input_tokens_usage, _output_tokens_usage)
+            else:
+                self.tool_uses = _tool_uses
+                self.input_tokens_usage = _input_tokens_usage
+                self.output_tokens_usage = _output_tokens_usage
+
         except GeneratorExit as e:
             logger.warning(f"Stream processing interrupted: {e}")
         finally:
