@@ -87,17 +87,11 @@ class ToolEventHandler:
         self.chat_window.display_status_message(f"Error in tool {tool_use['name']}")
 
         # Reset the current response bubble so the next agent message starts in a new bubble
+        self.chat_window.message_event_handler.chunk_buffer_queue = []
+        self.chat_window.message_event_handler.think_buffer_queue = []
         self.chat_window.current_response_bubble = None
         self.chat_window.current_response_container = None
 
-        if self.chat_window.current_thinking_bubble:
-            self.chat_window.current_thinking_bubble.raw_text_buffer = (
-                self.chat_window.thinking_content
-            )
-            self.chat_window.current_thinking_bubble._finalize_streaming()
-            self.chat_window.current_thinking_bubble = None
-        self.chat_window.thinking_content = ""
-
     def handle_tool_confirmation_required(self, tool_info):
         """Display a dialog for tool confirmation request."""
         tool_use = tool_info.copy()
@@ -213,3 +207,8 @@ class ToolEventHandler:
         self.chat_window.display_status_message(
             f"Tool execution rejected: {tool_use['name']}"
         )
+
+        self.chat_window.message_event_handler.chunk_buffer_queue = []
+        self.chat_window.message_event_handler.think_buffer_queue = []
+        self.chat_window.current_response_bubble = None
+        self.chat_window.current_response_container = None
