@@ -1,16 +1,17 @@
 from typing import Optional
 import markdown
 import os
+import sys
 import mimetypes
 
 from PySide6.QtWidgets import (
     QVBoxLayout,
     QLabel,
     QFrame,
+    QSizePolicy,
     QPushButton,
     QHBoxLayout,
     QFileIconProvider,
-    QScrollArea,
     QMenu,
 )
 from PySide6.QtCore import Qt, QFileInfo, QByteArray, QTimer
@@ -130,25 +131,18 @@ class MessageBubble(QFrame):
                 self.style_provider.get_assistant_message_label_style()
             )
 
-        # Set the text content (convert Markdown to HTML)
-        if text:
-            self.raw_text = text
-            self.set_text(text)
-
         # Setup context menu
         self.message_label.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         self.message_label.customContextMenuRequested.connect(self.show_context_menu)
 
-        # self.message_label.setSizePolicy(
-        #     QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum
-        # )
-
         if text is not None:
             # Add to layout
             layout.addWidget(self.message_label)
 
         # Set size policies
-        # self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)
+        self.setSizePolicy(
+            QSizePolicy.Policy.MinimumExpanding, QSizePolicy.Policy.Minimum
+        )
 
         # For user messages, add hover button functionality
         if is_user and message_index is not None:
@@ -330,6 +324,11 @@ class MessageBubble(QFrame):
 
         self.resizeEvent = resize_event_wrapper
 
+        # Set the text content (convert Markdown to HTML)
+        if text:
+            self.raw_text = text
+            self.set_text(text)
+
     def show_context_menu(self, position):
         """Create and show context menu with standard text actions plus Copy as Markdown."""
         menu = QMenu(self)
@@ -353,14 +352,31 @@ class MessageBubble(QFrame):
         copy_markdown_action.triggered.connect(self.copy_as_markdown)
 
         copy_all_html_action = menu.addAction("Copy all as Html")
-        copy_all_html_action.triggered.connect(
-            lambda: pyperclip.copy(self.message_label.text())
-        )
+        copy_all_html_action.triggered.connect(self._copy_as_html)
 
         menu.setStyleSheet(self.style_provider.get_context_menu_style())
 
         menu.exec_(self.message_label.mapToGlobal(position))
 
+    def _copy_as_html(self):
+        html_content = self.message_label.text()
+        doc = QTextDocument()
+        doc.setHtml(html_content)
+        if sys.platform == "win32":
+            from AgentCrew.modules.gui.utils.wins_clipboard import (
+                copy_html_to_clipboard as win_copy_html,
+            )
+
+            win_copy_html(doc.toHtml(), self.raw_text)
+        elif sys.platform == "darwin":
+            from AgentCrew.modules.gui.utils.macos_clipboard import (
+                copy_html_to_clipboard as macos_copy_html,
+            )
+
+            macos_copy_html(doc.toHtml())
+        else:
+            pyperclip.copy(doc.toHtml())
+
     def _select_all_text(self):
         """Select all text in the message label."""
         try:
@@ -409,7 +425,20 @@ class MessageBubble(QFrame):
                 fragment = cursor.selection()
                 selected_html = fragment.toHtml()
 
-                pyperclip.copy(selected_html)
+                if sys.platform == "win32":
+                    from AgentCrew.modules.gui.utils.wins_clipboard import (
+                        copy_html_to_clipboard as win_copy_html,
+                    )
+
+                    win_copy_html(selected_html, selected_plain_text)
+                elif sys.platform == "darwin":
+                    from AgentCrew.modules.gui.utils.macos_clipboard import (
+                        copy_html_to_clipboard as macos_copy_html,
+                    )
+
+                    macos_copy_html(selected_html)
+                else:
+                    pyperclip.copy(selected_html)
         except Exception:
             try:
                 selected_text = self.message_label.selectedText()
@@ -503,9 +532,6 @@ class MessageBubble(QFrame):
             current_text = self.message_label.text()
             self.message_label.setText(current_text + new_chars)
 
-            # Auto-scroll to keep latest content visible
-            # self._ensure_visible()
-
     def _finalize_streaming(self):
         """Convert to formatted text once streaming is complete."""
         self.is_streaming = False
@@ -524,22 +550,6 @@ class MessageBubble(QFrame):
         if self.is_streaming:
             self._finalize_streaming()
 
-    def _ensure_visible(self):
-        """Ensure the latest content is visible by scrolling."""
-        try:
-            # Get the parent scroll area and scroll to bottom
-            parent = self.parent()
-            while parent and not isinstance(parent, QScrollArea):
-                parent = parent.parent()
-
-            if parent and hasattr(parent, "verticalScrollBar"):
-                scrollbar = parent.verticalScrollBar()
-                if scrollbar:
-                    scrollbar.setValue(scrollbar.maximum())
-        except Exception:
-            # Silently handle any scrolling errors to avoid disrupting streaming
-            pass
-
     def append_text(self, text):
         """Update method to handle both streaming and normal modes."""
         self.set_text(text)
