@@ -229,13 +229,13 @@ _DEEPINFRA_MODELS = [
         output_token_price_1m=0.2,
     ),
     Model(
-        id="Qwen/Qwen2.5-72B-Instruct",
+        id="Qwen/Qwen3-Coder-480B-A35B-Instruct",
         provider="deepinfra",
-        name="Qwen 2.5 72B Instruct",
-        description="Qwen2.5 is a model pretrained on a large-scale dataset of up to 18 trillion tokens, offering significant improvements in knowledge, coding, mathematics, and instruction following compared to its predecessor Qwen2",
-        capabilities=["text-generation", "vision", "tool_use"],
-        input_token_price_1m=0.05,
-        output_token_price_1m=0.1,
+        name="Qwen 3 Coder",
+        description="Qwen3-Coder-480B-A35B-Instruct is the Qwen3's most agentic code model",
+        capabilities=["text-generation", "tool_use", "stream"],
+        input_token_price_1m=0.4,
+        output_token_price_1m=1.6,
     ),
     Model(
         id="Qwen/Qwen3-235B-A22B",
